/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { PublicAccount } from 'symbol-sdk';
import { CommandOption, NetworkConfig, TransactionParameters } from '../../index';
/**
 * @class AbstractCommand
 * @package contracts
 * @since v0.1.0
 * @description Class that describes a token command for creating NIP13 compliant tokens.
 */
export declare class Context {
    /**
     * @description Standard revision
     */
    revision: number;
    /**
     * @description Execution actor
     */
    actor: PublicAccount;
    /**
     * @description Network configuration
     */
    network: NetworkConfig;
    /**
     * @description Transaction parameters
     */
    parameters: TransactionParameters;
    /**
     * @description Execution parameters
     */
    protected argv: CommandOption[] | undefined;
    constructor(
    /**
     * @description Standard revision
     */
    revision: number, 
    /**
     * @description Execution actor
     */
    actor: PublicAccount, 
    /**
     * @description Network configuration
     */
    network: NetworkConfig, 
    /**
     * @description Transaction parameters
     */
    parameters: TransactionParameters, 
    /**
     * @description Execution parameters
     */
    argv: CommandOption[] | undefined);
    /**
     * Read an input by its' `name` in `argv` options.
     *
     * @param   {string} name
     * @param   {Array<CommandOption>}   argv
     * @param   {any} defaultValue
     * @return  {CommandOption|undefined}
     */
    getInput<ValueType>(name: string, defaultValue: ValueType): ValueType;
    /**
     * Set the value of an input by its' `name` in `argv` options.
     *
     * @param   {string}      name
     * @param   {ValueType}   value
     * @return  {Context}
     */
    setInput<ValueType>(name: string, value: ValueType): Context;
}
