"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// internal dependencies
const index_1 = require("../../index");
/**
 * @class AbstractCommand
 * @package contracts
 * @since v0.1.0
 * @description Class that describes a token command for creating NIP13 compliant tokens.
 */
class Context {
    constructor(
    /**
     * @description Standard revision
     */
    revision, 
    /**
     * @description Execution actor
     */
    actor, 
    /**
     * @description Network configuration
     */
    network, 
    /**
     * @description Transaction parameters
     */
    parameters, 
    /**
     * @description Execution parameters
     */
    argv) {
        this.revision = revision;
        this.actor = actor;
        this.network = network;
        this.parameters = parameters;
        this.argv = argv;
    }
    /**
     * Read an input by its' `name` in `argv` options.
     *
     * @param   {string} name
     * @param   {Array<CommandOption>}   argv
     * @param   {any} defaultValue
     * @return  {CommandOption|undefined}
     */
    getInput(name, defaultValue) {
        if (undefined === this.argv || !this.argv.length) {
            return defaultValue;
        }
        // find by name and return value
        const it = this.argv.find(opt => opt.name === name);
        return it ? it.value : defaultValue;
    }
    /**
     * Set the value of an input by its' `name` in `argv` options.
     *
     * @param   {string}      name
     * @param   {ValueType}   value
     * @return  {Context}
     */
    setInput(name, value) {
        if (undefined === this.argv) {
            this.argv = [];
        }
        this.argv.push(new index_1.CommandOption(name, value));
        return this;
    }
}
exports.Context = Context;
