"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const symbol_sdk_1 = require("symbol-sdk");
/**
 * @class NetworkConfig
 * @package contracts
 * @since v0.3.0
 * @description Class that describes a network configuration for NIP13 tokens.
 */
class NetworkConfig {
    /**
     * Construct a network configuration object
     *
     * @param {string}      gatewayUrl
     * @param {NetworkType} networkType
     * @param {string}      generationHash
     * @param {MosaicId}    feeMosaicId
     */
    constructor(
    /**
     * @description The REST endpoint URL
     */
    gatewayUrl, 
    /**
     * @description The network type
     */
    networkType, 
    /**
     * @description The network generation hash
     */
    generationHash, 
    /**
     * @description The network fee mosaic id
     */
    feeMosaicId) {
        this.gatewayUrl = gatewayUrl;
        this.networkType = networkType;
        this.generationHash = generationHash;
        this.feeMosaicId = feeMosaicId;
        this.factoryHttp = new symbol_sdk_1.RepositoryFactoryHttp(gatewayUrl, networkType, generationHash);
    }
}
exports.NetworkConfig = NetworkConfig;
