/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { PublicAccount } from 'symbol-sdk';
/**
 * @class TokenPartition
 * @package models
 * @since v0.1.0
 * @description Model that describes partitions of tokens. A partition
 *              is created around an \a owner public key (32 bytes) and
 *              an \a amount (1-8 bytes) and a \a name
 */
export declare class TokenPartition {
    /**
     * @description The partition name
     */
    name: string;
    /**
     * @description The partition owner
     */
    owner: PublicAccount;
    /**
     * @description The partition account
     */
    account: PublicAccount;
    /**
     * @description The amount of the partition
     */
    amount: number;
    /**
     * Constructor for TokenIdentifier objects
     *
     * @param {UInt64} id
     */
    constructor(
    /**
     * @description The partition name
     */
    name: string, 
    /**
     * @description The partition owner
     */
    owner: PublicAccount, 
    /**
     * @description The partition account
     */
    account: PublicAccount, 
    /**
     * @description The amount of the partition
     */
    amount: number);
    /**
     * Comparison operator
     *
     * @param {TokenPartition} rhs
     * @return {boolean}
     */
    equals(rhs: TokenPartition): boolean;
}
