/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Deadline, UInt64 } from 'symbol-sdk';
/**
 * @class TransactionParameters
 * @package contracts
 * @since v0.3.0
 * @description Class that describes common transaction parameters for NIP13 tokens commands.
 */
export declare class TransactionParameters {
    /**
     * @description The transaction deadline
     */
    deadline: Deadline;
    /**
     * @description The transaction maxFee
     */
    maxFeeInt?: number | undefined;
    /**
     * @description The transaction maxFee
     */
    maxFee: UInt64 | undefined;
    /**
     * Construct an execution parameters instance
     *
     * @param {Deadline}            Deadline
     * @param {UInt64|undefined}    maxFee
     */
    constructor(
    /**
     * @description The transaction deadline
     */
    deadline?: Deadline, 
    /**
     * @description The transaction maxFee
     */
    maxFeeInt?: number | undefined);
}
