/**
 * @type SecuritiesRestriction
 * @package models
 * @since v0.5.1
 * @description Type that describes a securities restriction
 */
export declare type SecuritiesRestriction = {
    [op: number]: number;
};
/**
 * @type SecuritiesRestrictionSet
 * @package models
 * @since v0.5.1
 * @description Type that describes a set of restrictions
 */
export declare type SecuritiesRestrictionSet = {
    [field: string]: SecuritiesRestriction;
};
/**
 * @class SecuritiesRestrictions
 * @package models
 * @since v0.1.0
 * @description Model that describes the restrictions of internal securities.
 */
export declare class SecuritiesRestrictions {
    /**
     * @description Custom restriction entries
     */
    restrictions: SecuritiesRestrictionSet;
    /**
     * @description Base restrictions for security tokens
     * @summary Currently the default minimum value for restriction
     *          field 'User_Role' is set to 3.
     *
     * Values for the 'User_Role' field include:
     * - 1 = Target
     * - 2 = Holder
     * - 3 = Locker
     * - 4 = Guest
     */
    static readonly DEFAULT_ROLE_RESTRICTION: SecuritiesRestrictionSet;
    /**
     * Constructor for SecuritiesRestrictions objects
     *
     * @param {string} source
     */
    constructor(
    /**
     * @description Custom restriction entries
     */
    restrictions?: SecuritiesRestrictionSet);
}
