"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const symbol_sdk_1 = require("symbol-sdk");
/**
 * @class SecuritiesRestrictions
 * @package models
 * @since v0.1.0
 * @description Model that describes the restrictions of internal securities.
 */
class SecuritiesRestrictions {
    /**
     * Constructor for SecuritiesRestrictions objects
     *
     * @param {string} source
     */
    constructor(
    /**
     * @description Custom restriction entries
     */
    restrictions = {}) {
        this.restrictions = restrictions;
    }
}
exports.SecuritiesRestrictions = SecuritiesRestrictions;
/**
 * @description Base restrictions for security tokens
 * @summary Currently the default minimum value for restriction
 *          field 'User_Role' is set to 3.
 *
 * Values for the 'User_Role' field include:
 * - 1 = Target
 * - 2 = Holder
 * - 3 = Locker
 * - 4 = Guest
 */
SecuritiesRestrictions.DEFAULT_ROLE_RESTRICTION = {
    'User_Role': {
        [symbol_sdk_1.MosaicRestrictionType.LE]: 3
    }
};
