/**
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { PublicAccount } from 'symbol-sdk';
import { Service, TokenPartition, TokenIdentifier } from '../../../../index';
/**
 * @class PartitionService
 * @package services
 * @since v0.1.0
 * @description Class that describes a service around token partition features.
 */
export declare class PartitionService extends Service {
    /**
     * Read token partitions from token operators
     * network information.
     *
     * @param {TokenIdentifier}       tokenId     The token identifier.
     * @param {PublicAccount}         target      The deterministic account that represents the token.
     * @param {PublicAccount[]}       operators   The list of operators of said token.
     * @param {string}                descriptor  The token command descriptor used as a marker.
     * @return {TokenPartition[]}
     */
    getPartitionsFromNetwork(tokenId: TokenIdentifier, target: PublicAccount, operators: PublicAccount[], descriptor?: string): Promise<TokenPartition[]>;
}
